**********************
*PLEASE CITE PAPER AS:
*Zarach, Z.H., Parteka A. (2023). Export diversification and dependence on natural resources. Economic Modelling Volume 126, September 2023, 106436. https://doi.org/10.1016/j.econmod.2023.106436
***********************************************
*IF YOU USE REPLICATION PACKAGE, PLEASE CITE AS:
*Zarach, Z.H., & Parteka, A. (2023). Data accompanying the paper: Zarach and Parteka (2023), Export diversification and dependence on natural resources, Economic Modelling (Elsevier), 126 (2023) 106436. [Data set]. Gdańsk University of Technology. https://doi.org/10.34808/844p-8614

********************************************************************************************
*THIS DO.FILE PREPARES THE BASELINE DATABASE FOR REGRESSION PART AND FIGURES/TABLES CREATION
********************************************************************************************
clear all
set more off
cd "D:\NR_DECOMPOSITION\DATA"
use EconomicModelling_ZarachParteka_BaselineData.dta, clear

*Creating an ID variable
egen countryid=group(Exporter)
order countryid, before(Exporter)

*Standarizing income classification (CLS2018) variable (merging LM and UM class. into M - middle income)
replace CLS2018="M" if CLS2018=="LM" | CLS2018=="UM"

*Creating one relative Theil (RT) index variable (value of overall relative Theil is the same for all classifications); deleting relative Theil index variable calculated for individual classifications
gen RT=RTc_RC1
la var RT "Relative (weighted) Theil index"
foreach k in RC1 RC2 RC3 RC4 RC5{
drop RTc_`k'
} 
order RT, before (betweenRC1)

*Replacing missing values into 0 
foreach k in RC1 RC2 RC3 RC4 RC5{
foreach z in between`k' within`k'_r within`k'_nr RT_ir_`k' RT_inr_`k' Ec`k'_r Ew`k'_r Sc`k'_r Sc`k'_nr Scw`k' RCA`k' RCAspecres`k'{
replace `z'=0 if `z'==.
}
}
foreach z in RT Ec Ew RCA EcTECH_t ScTECH_t RT_int_TECH RT_it_TECH{
replace `z'=0 if `z'==.
}

*Calculating shares of decomposition components in total RT index
foreach k in RC1 RC2 RC3 RC4 RC5{
foreach z in between`k' within`k'_r within`k'_nr{ 
gen share_`z'=(`z'/RT)*100
la var share_`z' "% share of component `z' in overall RT"
replace share_`z'=0 if share_`z'==.
}
}
gen share_RT=100
order share_RT, before (share_betweenRC1)

*Generating indicator of country size (and its logarithm) - GDP (rgdpe/emp) Calculating logarithm of GDP (a control for the country size)
gen SIZE = rgdpe
la var SIZE "Expenditure-side real GDP in 2017 PPP US$"
gen ln_SIZE = ln(SIZE)
la var ln_SIZE "Logarithm of expenditure-side real GDP"

*Generating indicator of development level (and its logarithm) - output per employee (rgdpe/emp)
gen DEV= rgdpe/emp
la var DEV "Output per worker in 2017 PPP US$ (rgdpe/emp)"
gen ln_DEV = ln(DEV)
la var ln_DEV "Logarithm of output per worker"

*Expressing output per worker in 100k US$
gen DEVscaled = DEV/100000
la var DEVscaled "Output per worker expressed in 100k US$"
*Calculating square of DEVscaled
gen DEVscaled_sq = DEVscaled*DEVscaled
la var DEVscaled_sq "Square of output per worker expr. in 100k US$"

*Creating one year lags of rescaled output per worker variables (for robustness estimation purposes)
xtset countryid year
gen lag = l.DEVscaled
la var lag "One-year lag of DEVscaled variable"
gen lagsq = l.DEVscaled_sq
la var lagsq "One-year lag of DEVscaled_sq variable"

*Generating GDP per CAPITA variable
gen GDPpc=rgdpe/pop
la var GDPpc "GDP per capita in 2017 PPP US$ (rgdpe/pop)"

*Presenting share of resource (technological) exports in countries' total exports in a percentage form
foreach k in RC1 RC2 RC3 RC4 RC5{
gen share_`k' = Sc`k'_r*100
la var share_`k' "Share of resource exports in % form (`k' group)"
}

gen share_TECH = ScTECH_t*100
la var share_TECH "Share of technological exports in % form (TECH group)"

*Logarithms of explained variables
foreach z in RT RT_it_TECH RT_inr_RC1 RT_inr_RC2 RT_inr_RC3 RT_inr_RC4 RT_inr_RC5{
gen ln_`z' = ln(`z')
la var ln_`z' "Logarithm of variable `z'"
}

*Interpolating variable INST (because World Governance Indicators database does not provide data for years 1997, 1999 and 2001)
bysort Exporter: ipolate INST year , generate(INST_ip) epolate
replace INST_ip=0 if INST_ip<0
la var INST_ip "Quality of institutions, ipolated"
order INST_ip, after (INST)

*Interaction terms between share of resources and institution level
foreach k in RC1 RC2 RC3 RC4 RC5{
gen interaction_INST_`k' = Sc`k'_r*INST_ip
la var interaction_INST_`k' "Interaction term between Sc`k'_r and INST_ip variables"
}

*Creating a NR exporter variable
gen NR_exporter=.
foreach country in AGO ARE AUS AZE BHR BOL BRN CHL CMR COD COG DZA GAB GIN GNQ IRN IRQ JAM KAZ KWT MNG MOZ NGA NOR OMN QAT RUS SAU SDN TCD TJK TKM TTO VEN YEM ZMB {
replace NR_exporter = 1 if Exporter== "`country'"
}
replace NR_exporter = 0 if NR_exporter==.
la var NR_exporter "Countries with share of NR exports higher or equal than 50% (1996-2018 mean)"
order NR_exporter, after (CLS2018)


*Saving the final database
save EconomicModelling_ZarachParteka_FinalData.dta, replace



